@@ -43,7 +43,7 @@ def make_neu(station_0, input_res):
 
 class GeoJSONData(GeneralData):
     def __init__(self, *args, **kwargs):
-        super(GeoJSONData, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.station = kwargs['station']
         self.position = kwargs['position']  # has lat, lon, z reference
         #print("Inicializa GEOJSON")
@@ -60,7 +60,7 @@ class GeoJSONData(GeneralData):
 
         try:
             # TIME OK
-            dt0 = gps_time(data)
+            dt0, source = gps_time(data)
             time = int(dt0.timestamp()*1000)
 
             # GET STATION REF AND NEW DATA
@@ -84,27 +84,26 @@ class GeoJSONData(GeneralData):
                 #bprint("Calculating VCV rotation: matrix-->%s" %self.rotation_matrix)
                 VCV = all_in_one_vcv(self.rotation_matrix,
                                      data['POSITION_VCV'])
-                sncl='{}.FU.LY_.00'.format(self.station['code'])
+                sncl = '{}.FU.LY_.00'.format(self.station['code'])
                 prop = {'quality': 100,
                         'EError': math.sqrt(VCV['EE']),
                         'NError': math.sqrt(VCV['NN']),
                         'UError': math.sqrt(VCV['UU']),
                         'time': time,
                         'dt': dt0,
-                        'DT_GEN': dtgen,
+                        'dt_gen': dtgen,
                         'sampleRate': 1,
                         'station': self.station['code'],
-                        'SNCL':sncl }
+                        'SNCL': sncl}
             else:
                 prop = {'quality': 100,
                         'time': time,
                         'dt': dt0,
-                        'DT_GEN': dtgen,
+                        'dt_gen': dtgen,
                         'sampleRate': 1,
                         'station': self.station['code'],
                         'SNCL': '{}.FU.LY_.00'.format(self.station['code'])}
 
-
             data = {'features': [{'geometry': {'coordinates': geo['coordinates'],
                                                'type': 'Point'},
                                   'type': 'Feature',
@@ -115,5 +114,6 @@ class GeoJSONData(GeneralData):
             #rprint("Form GeoJson process, data to send: %s" %data)
         except Exception as ex:
             print("Error en conversion de JSON %s " % ex)
+            self.logger.exception(ex)
             raise ex
         return data
